gotrue library

Classes

AdminUserAttributes
AMREntry
An authentication method reference (AMR) entry.
ApiVersions
AuthMFAAdminDeleteFactorResponse
AuthMFAAdminListFactorsResponse
AuthMFAChallengeResponse
AuthMFAEnrollResponse
AuthMFAGetAuthenticatorAssuranceLevelResponse
AuthMFAListFactorsResponse
AuthMFAUnenrollResponse
AuthMFAVerifyResponse
AuthResponse
Response which might or might not contain session and/or user
AuthSessionUrlResponse
AuthState
CreateOAuthClientParams
Parameters for creating a new OAuth client. Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
DecodedJwt
Decoded JWT structure
Factor
GenerateLinkProperties
GenerateLinkResponse
GetClaimsOptions
Options for getClaims method
GetClaimsResponse
Response from getClaims method
GoTrueAdminApi
GotrueAsyncStorage
Interface to provide async storage to store pkce tokens.
GoTrueClient
API client to interact with gotrue server.
GoTrueMFAApi
JWK
JSON Web Key (JWK) representation.
JWKSet
JwtHeader
JWT Header structure
JwtPayload
JWT Payload structure with standard claims
JwtRawParts
Raw encoded parts of a JWT
OAuthClient
OAuth client object returned from the OAuth 2.1 server. Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
OAuthProvider
An OAuth provider identifier.
OAuthResponse
Response of OAuth signin
PhoneEnrollment
ResendResponse
Session
TOTPEnrollment
UpdateOAuthClientParams
Parameters for updating an existing OAuth client. Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
User
UserAttributes
UserIdentity
UserResponse
Response that contains a user

Enums

AMRMethod
AuthChangeEvent
AuthenticatorAssuranceLevels
AuthFlowType
FactorStatus
FactorType
GenerateLinkType
OAuthClientGrantType
OAuth client grant types supported by the OAuth 2.1 server. Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
OAuthClientRegistrationType
OAuth client registration type. Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
OAuthClientResponseType
OAuth client response types supported by the OAuth 2.1 server. Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
OAuthClientType
OAuth client type indicating whether the client can keep credentials confidential. Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
OtpChannel
Messaging channel to use (e.g. whatsapp or sms)
OtpType
SignOutScope
Determines which sessions should be logged out.

Functions

decodeJwt(String token) DecodedJwt
Decodes a JWT token without performing validation
validateExp(int? exp) → void
Validates the expiration time of a JWT

Typedefs

BroadcastChannel = ({void Function() close, Stream<Map<String, dynamic>> onMessage, void Function(Map) postMessage})